@@ -33,7 +33,7 @@ import colemen_utilities.string_utils as _csu
 # logger = _logging.getLogger(__name__)
 from dataclasses import dataclass
 import os
-from typing import Union
+from typing import Iterable, Union
 from os import scandir, stat
 from stat import (
     FILE_ATTRIBUTE_ARCHIVE as A,
@@ -150,6 +150,7 @@ class Directory:
     _encrypt:bool = None
     _compressed:bool = None
     _attribs:dict = None
+    _files:list = None
 
     def __init__(self,file_path:str) -> None:
         self.file_path = file_path
@@ -668,24 +669,6 @@ class Directory:
 
         return _comp.create_zip(self.file_path,dst,delete_after=delete_after,overwrite=overwrite)
 
-    @property
-    def files(self):
-        '''
-            Get this dir's files
-
-            `default`:None
-
-
-            Meta
-            ----------
-            `@author`: Colemen Atwood
-            `@created`: 02-23-2023 08:34:16
-            `@memberOf`: dir
-            `@property`: files
-        '''
-        value = _f.get_files(self.file_path,recursive=False)
-        return value
-
     def delete(self,shred:bool=False):
         '''
             Delete this directory
@@ -824,8 +807,146 @@ class Directory:
         # value = self.most_recent_modification
         return value
 
-    def has_file(self,file_name):
-        return _f.exists(f"{self.file_path}/{file_name}")
+
+    @property
+    def files(self)->Iterable[_config._file_type]:
+        '''
+            Get this dir's files
+
+            `default`:None
+
+
+            Meta
+            ----------
+            `@author`: Colemen Atwood
+            `@created`: 02-23-2023 08:34:16
+            `@memberOf`: dir
+            `@property`: files
+        '''
+        value = self._files
+        if value is None:
+            value = self.get_files()
+        # value = _f.get_files(self.file_path,recursive=False)
+        return self._files
+
+
+
+
+    # @property
+    def get_files(
+        self,
+        recursive:bool=False,
+        exclude:Union[str,list]=None,
+        include:Union[str,list]=None,
+        extensions:Union[str,list]=None,
+        )->Iterable[_config._file_type]:
+        '''
+            Get all files/data from this directory.
+
+            ----------
+
+            Keyword Arguments
+            -----------------
+                [`search_path`=cwd] {str|list}
+                    The search path or list of paths to iterate.
+
+                [`recursive`=False] {boolean}
+                    If True the path is iterated recursively
+
+                [`exclude`=[]] {str|list}
+                    A term or list or terms to ignore if the file path contains any of them.
+
+                [`extensions|ext|extension`=[]] {str|list}
+                    An extension or list of extensions that the file must have.\n
+                    Can have leading periods or not.\n
+                    if equal to "images" it will automatically search for these extensions:
+                        bmp,dds,dib,eps,gif,icns,ico,im,jpg,jpeg,jpeg 2000,msp,pcx,png,ppm,sgi,spider,tga,tiff,webp,xbm
+
+            return
+            ----------
+            `return` {list}
+                A list of file instances.
+        '''
+
+        value = _f.get_files_obj(
+            self.file_path,
+            recursive=recursive,
+            exclude=exclude,
+            include=include,
+            extensions=extensions,
+        )
+        self._files:Iterable[_config._file_type] = value
+        return value
+
+    def has_file(self,file_name)->Union[_config._file_type,bool]:
+        '''
+            Check if this directory contains a file with a matching name.
+            ----------
+
+            Arguments
+            -------------------------
+            `file_name` {str}
+                The name to search for it must match exactly.
+                The extension is not required, but obviously can cause issues if there are multiple
+                files with the same name and different extensions.
+
+            Return {file,bool}
+            ----------------------
+            The file object if the file exists, False otherwise.
+
+            Meta
+            ----------
+            `author`: Colemen Atwood
+            `created`: 03-01-2023 08:39:45
+            `memberOf`: dir
+            `version`: 1.0
+            `method_name`: has_file
+            * @xxx [03-01-2023 08:42:31]: documentation for has_file
+        '''
+        ext = _f.get_ext(file_name)
+        for f in self.files:
+            if ext is False:
+                if f.name_no_ext == file_name:
+                    return f
+            else:
+                if f.name == file_name:
+                    return f
+        if _f.exists(f"{self.file_path}/{file_name}"):
+            return _f.get_file(f"{self.file_path}/{file_name}")
+        return False
+
+    # def get_file(self,file_name)->_config._file_type:
+    #     '''
+    #         Retrieve a file object from this directory
+    #         ----------
+
+    #         Arguments
+    #         -------------------------
+    #         `arg_name` {type}
+    #             arg_description
+
+    #         Keyword Arguments
+    #         -------------------------
+    #         `arg_name` {type}
+    #             arg_description
+
+    #         Return {type}
+    #         ----------------------
+    #         return_description
+
+    #         Meta
+    #         ----------
+    #         `author`: Colemen Atwood
+    #         `created`: 03-01-2023 08:42:39
+    #         `memberOf`: dir
+    #         `version`: 1.0
+    #         `method_name`: get_file
+    #         * @TODO []: documentation for get_file
+    #     '''
+    #     result = None
+    #     if self.has_file(file_name) is True:
+    #         result = _f.get_file(f"{self.file_path}/{file_name}")
+    #     return result
 
 
 
