@@ -65,6 +65,8 @@ def gen_variations(value):
 
 def number(minimum=1,maximum=100):
     return _random.randint(minimum,maximum)
+integer = number
+
 
 def boolean(bias=50):
     return _random.randint(1,100) <= bias
@@ -293,11 +295,184 @@ def text(minimum=10,maximum=500,null_bias=0):
     val = val.replace("'","")
     return val
 
+# word = faker().english_word
+# '''Generate a random english word'''
+
 def ip_address(bias=100):
     if faker().boolean(bias):
         return faker().ipv4()
     return None
 
+host_name = faker().hostname
+'''Generate a random web host name'''
+def hostname():
+    '''
+        Generate a random hostname name
+        ----------
+
+        Return {str}
+        ----------------------
+        A random hostname name
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 03-07-2023 08:50:50
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: hostname
+        * @xxx [03-07-2023 08:51:54]: documentation for hostname
+    '''
+    return faker().hostname()
+
+def http_method():
+    '''
+        Generate a random http_method name
+        ----------
+
+        Return {str}
+        ----------------------
+        A random http_method name
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 03-07-2023 08:50:50
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: http_method
+        * @xxx [03-07-2023 08:51:54]: documentation for http_method
+    '''
+    return faker().http_method()
+
+def user_agent_chrome():
+    '''
+        Generate a random user_agent_chrome name
+        ----------
+
+        Return {str}
+        ----------------------
+        A random user_agent_chrome name
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 03-07-2023 08:50:50
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: user_agent_chrome
+        * @xxx [03-07-2023 08:51:54]: documentation for user_agent_chrome
+    '''
+    return faker().chrome()
+
+def user_agent_firefox():
+    '''
+        Generate a random user_agent_firefox name
+        ----------
+
+        Return {str}
+        ----------------------
+        A random user_agent_firefox name
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 03-07-2023 08:50:50
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: user_agent_firefox
+        * @xxx [03-07-2023 08:51:54]: documentation for user_agent_firefox
+    '''
+    return faker().firefox()
+
+
+def user_agent_internet_explorer():
+    '''
+        Generate a random user_agent_internet_explorer name
+        ----------
+
+        Return {str}
+        ----------------------
+        A random user_agent_internet_explorer name
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 03-07-2023 08:50:50
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: user_agent_internet_explorer
+        * @xxx [03-07-2023 08:51:54]: documentation for user_agent_internet_explorer
+    '''
+    return faker().internet_explorer()
+
+
+def user_agent_opera():
+    '''
+        Generate a random user_agent_opera name
+        ----------
+
+        Return {str}
+        ----------------------
+        A random user_agent_opera name
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 03-07-2023 08:50:50
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: user_agent_opera
+        * @xxx [03-07-2023 08:51:54]: documentation for user_agent_opera
+    '''
+    return faker().opera()
+
+def user_agent_safari():
+    '''
+        Generate a random user_agent_safari name
+        ----------
+
+        Return {str}
+        ----------------------
+        A random user_agent_safari name
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 03-07-2023 08:50:50
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: user_agent_safari
+        * @xxx [03-07-2023 08:51:54]: documentation for user_agent_safari
+    '''
+    return faker().safari()
+
+def user_agent():
+    '''
+        Generate a random user_agent name
+        ----------
+
+        Return {str}
+        ----------------------
+        A random user_agent name
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 03-07-2023 08:50:50
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: user_agent
+        * @xxx [03-07-2023 08:51:54]: documentation for user_agent
+    '''
+    return faker().user_agent()
+
+
+
+
+
+
+
 def phone(bias=100):
     '''
         Generate a random phone number or None.
@@ -1217,3 +1392,120 @@ def file_path(**kwargs):
     return path
 
 
+
+# ---------------------------------------------------------------------------- #
+#                              GEOGRAPHY / ADDRESS                             #
+# ---------------------------------------------------------------------------- #
+
+
+def country():
+    '''
+        Generate a random country name
+        ----------
+
+        Return {str}
+        ----------------------
+        A random country name
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 03-07-2023 08:50:50
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: country
+        * @xxx [03-07-2023 08:51:52]: documentation for country
+    '''
+    return faker().country()
+
+def city():
+    '''
+        Generate a random city name
+        ----------
+
+        Return {str}
+        ----------------------
+        A random city name
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 03-07-2023 08:50:50
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: city
+        * @xxx [03-07-2023 08:51:54]: documentation for city
+    '''
+    return faker().city()
+
+def postcode():
+    '''
+        Generate a random postcode name
+        ----------
+
+        50995
+
+        Return {str}
+        ----------------------
+        A random postcode name
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 03-07-2023 08:50:50
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: postcode
+        * @xxx [03-07-2023 08:51:54]: documentation for postcode
+    '''
+    return faker().postcode()
+zipcode = postcode
+
+def street_address():
+    '''
+        Generate a random street_address name
+        ----------
+
+        Return {str}
+        ----------------------
+        A random street_address name
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 03-07-2023 08:50:50
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: street_address
+        * @xxx [03-07-2023 08:51:54]: documentation for street_address
+    '''
+    return faker().street_address()
+
+
+def state():
+    '''
+        Generate a random state name
+        ----------
+
+        Return {str}
+        ----------------------
+        A random state name
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 03-07-2023 08:50:50
+        `memberOf`: rand_generation
+        `version`: 1.0
+        `method_name`: state
+        * @xxx [03-07-2023 08:51:54]: documentation for state
+    '''
+    return faker().state()
+
+latitude = faker().latitude()
+'''Randomly generate a latitudinal coordinate'''
+longitude = faker().longitude()
+'''Randomly generate a longitudinal coordinate'''
+
+
+
