@@ -136,8 +136,9 @@ def strip_excessive_chars(value:str,chars:_Union[str,list])->str:
         chars = [chars]
     for c in chars:
         if c == " ":
-            c = "\\s"
-
+            value = _re.sub(r'[\s]{2,}',' ',value)
+            value = _re.sub(r',\s*,',', ',value)
+            continue
         reg_c = _csu.escape_regex(c)
         exp = rf"[{reg_c}]{{2,}}"
         # print(exp)
